@@ -382,7 +382,7 @@ class WorkspaceJob(Job):
         workspace_path: The mount path for workspace volume.
         outputs_path: The mount path for outputs volume
     """
-    def __init__(self, job_name, namespace='default', workspace_path="/workspace/", output_path=None, workspace_size="1", output_size="1"):
+    def __init__(self, job_name, namespace='default', workspace_path="/workspace/", output_path=None, workspace_size="1", output_size="1", shared_claim_name=None):
         super().__init__(job_name, namespace)
         self.workspace_path = workspace_path
         if not self.workspace_path.endswith("/"):
@@ -393,6 +393,7 @@ class WorkspaceJob(Job):
 
         self.workspace_size = workspace_size
         self.output_size = output_size
+        self.shared_claim_name = shared_claim_name
 
         self.job_spec = dict(backoff_limit=0)
         self.workspace_vc = None
@@ -408,33 +409,46 @@ class WorkspaceJob(Job):
 
     def _add_volumes(self):
         # See https://github.com/kubernetes-client/python/blob/master/kubernetes/docs/V1Volume.md
-        self.workspace_vc = VolumeClaim(self.job_name+"-wvc", self.workspace_size, self.namespace)
-        wrkspc_response = self.workspace_vc.create()
-        self.add_volume(
-            name="workspace",
-            persistent_volume_claim=client.V1PersistentVolumeClaimVolumeSource(
-                claim_name=self.job_name+"-wvc"
-            )
-        )
-
-        # See https://github.com/kubernetes-client/python/blob/master/kubernetes/docs/V1VolumeMount.md
-        volume_mounts = [
-            client.V1VolumeMount(mount_path=self.workspace_path, name="workspace"),
-        ]
-        # Add output volume, if outputs_path is not the same as the workspace_path.
-        if self.outputs_path and self.outputs_path != self.workspace_path:
-            self.outputs_vc = VolumeClaim(self.job_name+"-ovc", self.output_size, self.namespace)
-            out_response = self.outputs_vc.create()
+        if not self.shared_claim_name:
+            self.workspace_vc = VolumeClaim(self.job_name+"-wvc", self.workspace_size, self.namespace)
+            wrkspc_response = self.workspace_vc.create()
             self.add_volume(
-                name="outputs",
+                name="workspace",
                 persistent_volume_claim=client.V1PersistentVolumeClaimVolumeSource(
-                    claim_name=self.job_name+"-ovc"
+                    claim_name=self.job_name+"-wvc"
                 )
             )
-            volume_mounts.append(
-                client.V1VolumeMount(mount_path=self.outputs_path, name="outputs"),
+
+            # See https://github.com/kubernetes-client/python/blob/master/kubernetes/docs/V1VolumeMount.md
+            volume_mounts = [
+                client.V1VolumeMount(mount_path=self.workspace_path, name="workspace"),
+            ]
+            # Add output volume, if outputs_path is not the same as the workspace_path.
+            if self.outputs_path and self.outputs_path != self.workspace_path:
+                self.outputs_vc = VolumeClaim(self.job_name+"-ovc", self.output_size, self.namespace)
+                out_response = self.outputs_vc.create()
+                self.add_volume(
+                    name="outputs",
+                    persistent_volume_claim=client.V1PersistentVolumeClaimVolumeSource(
+                        claim_name=self.job_name+"-ovc"
+                    )
+                )
+                volume_mounts.append(
+                    client.V1VolumeMount(mount_path=self.outputs_path, name="outputs"),
+                )
+        else:
+            self.workspace_vc = VolumeClaim(self.shared_claim_name, self.workspace_size, self.namespace, "filestore-hdd", ['ReadWriteMany'])
+            self.add_volume(
+                name="workspace",
+                persistent_volume_claim=client.V1PersistentVolumeClaimVolumeSource(
+                    claim_name=self.shared_claim_name
+                )
             )
 
+            # See https://github.com/kubernetes-client/python/blob/master/kubernetes/docs/V1VolumeMount.md
+            volume_mounts = [
+                client.V1VolumeMount(mount_path=self.workspace_path, name="workspace"),
+            ]
         return volume_mounts
 
     def run_containers(self, containers, composition='sequential'):
@@ -588,6 +602,8 @@ class WorkspaceJob(Job):
             kwargs["output_size"] = config.get("output_size")
         if "preemptible" not in kwargs and config.get("preemptible"):
             kwargs["preemptible"] = config.get("preemptible")
+        if "shared_claim_name" not in kwargs and config.get("shared_claim_name"):
+            kwargs["shared_claim_name"] = config.get("shared_claim_name")
 
         env_dict = dict()
 
