@@ -8,12 +8,12 @@ logger = logging.getLogger(__name__)
 class VolumeClaim:
     """Represents a volume claim.
     """
-    def __init__(self, claim_name, disk_space, namespace='default', storage_class="standard-fc"):
+    def __init__(self, claim_name, disk_space, namespace='default', storage_class="standard-fc", access_modes=['ReadWriteOnce']):
         """ Initialize a VolumeClaim object
         """
         self.name = claim_name
         self.namespace = namespace
-        self.vc_spec = dict(access_modes=['ReadWriteOnce'], storage_class_name=storage_class)
+        self.vc_spec = dict(access_modes=access_modes, storage_class_name=storage_class)
         self.disk_space = disk_space
 
     @staticmethod
